# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.explain_retriever_response import ExplainRetrieverResponse

class TestExplainRetrieverResponse(unittest.TestCase):
    """ExplainRetrieverResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExplainRetrieverResponse:
        """Test ExplainRetrieverResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExplainRetrieverResponse`
        """
        model = ExplainRetrieverResponse()
        if include_optional:
            return ExplainRetrieverResponse(
                retriever_id = '',
                retriever_name = '',
                estimated_cost = {
                    'key' : 1.337
                    },
                execution_plan = [
                    mixpeek.models.explain_stage_plan.ExplainStagePlan(
                        stage_index = 0.0, 
                        stage_name = '', 
                        stage_type = '', 
                        estimated_input = 0.0, 
                        estimated_output = 0.0, 
                        estimated_efficiency = 0.0, 
                        estimated_cost_credits = 0.0, 
                        estimated_duration_ms = 0.0, 
                        cache_likely = True, 
                        optimization_notes = [
                            ''
                            ], 
                        warnings = [
                            ''
                            ], )
                    ],
                optimization_suggestions = [
                    None
                    ],
                total_estimated_stages = 0.0,
                bottleneck_stages = [
                    ''
                    ],
                optimization_level = 'mvp',
                optimization_applied = True,
                optimization_details = mixpeek.models.optimization_details.Optimization Details()
            )
        else:
            return ExplainRetrieverResponse(
                retriever_id = '',
                retriever_name = '',
                estimated_cost = {
                    'key' : 1.337
                    },
                total_estimated_stages = 0.0,
        )
        """

    def testExplainRetrieverResponse(self):
        """Test ExplainRetrieverResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.batch_upload_response import BatchUploadResponse

class TestBatchUploadResponse(unittest.TestCase):
    """BatchUploadResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchUploadResponse:
        """Test BatchUploadResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchUploadResponse`
        """
        model = BatchUploadResponse()
        if include_optional:
            return BatchUploadResponse(
                uploads = [
                    mixpeek.models.upload_response.UploadResponse(
                        upload_id = '', 
                        bucket_id = '', 
                        filename = '', 
                        content_type = '', 
                        file_size_bytes = 56, 
                        presigned_url = '0', 
                        presigned_url_expiration = 56, 
                        s3_key = '', 
                        status = null, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = '', 
                        blob_type = '', 
                        file_hash = '', 
                        skip_duplicates = True, 
                        is_duplicate = True, 
                        duplicate_of_upload_id = '', 
                        skipped_unique_key = True, 
                        existing_object_id = '', 
                        message = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        object_id = '', 
                        task_id = '', )
                    ],
                total = 56
            )
        else:
            return BatchUploadResponse(
                uploads = [
                    mixpeek.models.upload_response.UploadResponse(
                        upload_id = '', 
                        bucket_id = '', 
                        filename = '', 
                        content_type = '', 
                        file_size_bytes = 56, 
                        presigned_url = '0', 
                        presigned_url_expiration = 56, 
                        s3_key = '', 
                        status = null, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = '', 
                        blob_type = '', 
                        file_hash = '', 
                        skip_duplicates = True, 
                        is_duplicate = True, 
                        duplicate_of_upload_id = '', 
                        skipped_unique_key = True, 
                        existing_object_id = '', 
                        message = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        object_id = '', 
                        task_id = '', )
                    ],
                total = 56,
        )
        """

    def testBatchUploadResponse(self):
        """Test BatchUploadResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.feature_model import FeatureModel

class TestFeatureModel(unittest.TestCase):
    """FeatureModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FeatureModel:
        """Test FeatureModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FeatureModel`
        """
        model = FeatureModel()
        if include_optional:
            return FeatureModel(
                feature_extractor_id = '',
                payload = mixpeek.models.payload.Payload(),
                vectors = None
            )
        else:
            return FeatureModel(
                feature_extractor_id = '',
        )
        """

    def testFeatureModel(self):
        """Test FeatureModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr, field_validator
from typing import Optional, Union
from typing_extensions import Annotated
from mixpeek.models.batch_diagnostics import BatchDiagnostics
from mixpeek.models.bottleneck_response import BottleneckResponse
from mixpeek.models.engine_performance_response import EnginePerformanceResponse
from mixpeek.models.engine_stage_breakdown_response import EngineStageBreakdownResponse
from mixpeek.models.extractor_breakdown_response import ExtractorBreakdownResponse
from mixpeek.models.slow_operations_response import SlowOperationsResponse

from mixpeek.api_client import ApiClient, RequestSerialized
from mixpeek.api_response import ApiResponse
from mixpeek.rest import RESTResponseType


class AnalyticsPerformanceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def analyze_bottlenecks_analytics_performance_engine(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=1)]], Field(description="Number of bottlenecks to return")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BottleneckResponse:
        """Analyze Bottlenecks

        Identify performance bottlenecks.  Analyzes profiling data to identify the biggest bottlenecks, ranked by total time spent.  **Use Cases:** - Find what's slowing down your pipelines - Prioritize optimization efforts - Monitor bottleneck trends  **Ranking:** - Sorted by total time spent (sum across all executions) - Shows percentage of total execution time - Includes execution count and average time  **Example:** ```bash GET /v1/analytics/performance/engine/bottlenecks?hours=24&limit=10 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of bottlenecks to return
        :type limit: int
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analyze_bottlenecks_analytics_performance_engine_serialize(
            hours=hours,
            limit=limit,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BottleneckResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def analyze_bottlenecks_analytics_performance_engine_with_http_info(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=1)]], Field(description="Number of bottlenecks to return")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BottleneckResponse]:
        """Analyze Bottlenecks

        Identify performance bottlenecks.  Analyzes profiling data to identify the biggest bottlenecks, ranked by total time spent.  **Use Cases:** - Find what's slowing down your pipelines - Prioritize optimization efforts - Monitor bottleneck trends  **Ranking:** - Sorted by total time spent (sum across all executions) - Shows percentage of total execution time - Includes execution count and average time  **Example:** ```bash GET /v1/analytics/performance/engine/bottlenecks?hours=24&limit=10 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of bottlenecks to return
        :type limit: int
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analyze_bottlenecks_analytics_performance_engine_serialize(
            hours=hours,
            limit=limit,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BottleneckResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def analyze_bottlenecks_analytics_performance_engine_without_preload_content(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=1)]], Field(description="Number of bottlenecks to return")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Analyze Bottlenecks

        Identify performance bottlenecks.  Analyzes profiling data to identify the biggest bottlenecks, ranked by total time spent.  **Use Cases:** - Find what's slowing down your pipelines - Prioritize optimization efforts - Monitor bottleneck trends  **Ranking:** - Sorted by total time spent (sum across all executions) - Shows percentage of total execution time - Includes execution count and average time  **Example:** ```bash GET /v1/analytics/performance/engine/bottlenecks?hours=24&limit=10 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of bottlenecks to return
        :type limit: int
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analyze_bottlenecks_analytics_performance_engine_serialize(
            hours=hours,
            limit=limit,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BottleneckResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _analyze_bottlenecks_analytics_performance_engine_serialize(
        self,
        hours,
        limit,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if hours is not None:
            
            _query_params.append(('hours', hours))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/engine/bottlenecks',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_batch_diagnostics_analytics_performance_batches(
        self,
        batch_id: StrictStr,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BatchDiagnostics:
        """Get Batch Diagnostics

        Get comprehensive diagnostics for a batch.  Combines batch status, task progress, collection info, performance metrics, and actionable insights into a single response for easy frontend rendering.  **Use Cases:** - Monitor batch processing in real-time - Debug failed batches - View performance breakdown after completion - Get actionable next steps  **Response includes:** - Overall batch status and progress - Per-tier task details with Ray job links - Collection document counts - Performance insights and bottlenecks (if completed) - Error details (if failed) - Recommended next actions  **Example:** ```bash GET /v1/analytics/performance/batches/{batch_id}/diagnostics ```  **Perfect for:** - Real-time progress tracking UI - Batch monitoring dashboards - Debugging failed extractions - Performance optimization

        :param batch_id: (required)
        :type batch_id: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_batch_diagnostics_analytics_performance_batches_serialize(
            batch_id=batch_id,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BatchDiagnostics",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_batch_diagnostics_analytics_performance_batches_with_http_info(
        self,
        batch_id: StrictStr,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BatchDiagnostics]:
        """Get Batch Diagnostics

        Get comprehensive diagnostics for a batch.  Combines batch status, task progress, collection info, performance metrics, and actionable insights into a single response for easy frontend rendering.  **Use Cases:** - Monitor batch processing in real-time - Debug failed batches - View performance breakdown after completion - Get actionable next steps  **Response includes:** - Overall batch status and progress - Per-tier task details with Ray job links - Collection document counts - Performance insights and bottlenecks (if completed) - Error details (if failed) - Recommended next actions  **Example:** ```bash GET /v1/analytics/performance/batches/{batch_id}/diagnostics ```  **Perfect for:** - Real-time progress tracking UI - Batch monitoring dashboards - Debugging failed extractions - Performance optimization

        :param batch_id: (required)
        :type batch_id: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_batch_diagnostics_analytics_performance_batches_serialize(
            batch_id=batch_id,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BatchDiagnostics",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_batch_diagnostics_analytics_performance_batches_without_preload_content(
        self,
        batch_id: StrictStr,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Batch Diagnostics

        Get comprehensive diagnostics for a batch.  Combines batch status, task progress, collection info, performance metrics, and actionable insights into a single response for easy frontend rendering.  **Use Cases:** - Monitor batch processing in real-time - Debug failed batches - View performance breakdown after completion - Get actionable next steps  **Response includes:** - Overall batch status and progress - Per-tier task details with Ray job links - Collection document counts - Performance insights and bottlenecks (if completed) - Error details (if failed) - Recommended next actions  **Example:** ```bash GET /v1/analytics/performance/batches/{batch_id}/diagnostics ```  **Perfect for:** - Real-time progress tracking UI - Batch monitoring dashboards - Debugging failed extractions - Performance optimization

        :param batch_id: (required)
        :type batch_id: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_batch_diagnostics_analytics_performance_batches_serialize(
            batch_id=batch_id,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BatchDiagnostics",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_batch_diagnostics_analytics_performance_batches_serialize(
        self,
        batch_id,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if batch_id is not None:
            _path_params['batch_id'] = batch_id
        # process the query parameters
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/batches/{batch_id}/diagnostics',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_engine_performance_analytics(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history (alternative to date range)")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date for time range")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date for time range")] = None,
        group_by: Annotated[Optional[Annotated[str, Field(strict=True)]], Field(description="Time grouping (minute, hour, day, week)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EnginePerformanceResponse:
        """Get Engine Performance

        Get engine performance metrics over time.  Query profiling data logged by the engine's profiling infrastructure. All queries are automatically filtered to your namespace.  **Time Range:** - Specify `hours` for recent history (e.g., `hours=24` for last 24 hours) - OR specify `start_date` and `end_date` for custom range - Defaults to last 24 hours if neither provided  **Grouping:** - `minute`: High-resolution (for short time ranges) - `hour`: Standard resolution (default) - `day`: For longer time ranges - `week`, `month`: For historical trends  **Response:** - Time-series metrics (avg, p50, p95, p99 latencies) - Summary statistics across the entire time range - All latencies in milliseconds  **Example:** ```bash GET /v1/analytics/performance/engine?hours=24&group_by=hour ```

        :param hours: Hours of history (alternative to date range)
        :type hours: int
        :param start_date: Start date for time range
        :type start_date: datetime
        :param end_date: End date for time range
        :type end_date: datetime
        :param group_by: Time grouping (minute, hour, day, week)
        :type group_by: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_performance_analytics_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            group_by=group_by,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EnginePerformanceResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_engine_performance_analytics_with_http_info(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history (alternative to date range)")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date for time range")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date for time range")] = None,
        group_by: Annotated[Optional[Annotated[str, Field(strict=True)]], Field(description="Time grouping (minute, hour, day, week)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EnginePerformanceResponse]:
        """Get Engine Performance

        Get engine performance metrics over time.  Query profiling data logged by the engine's profiling infrastructure. All queries are automatically filtered to your namespace.  **Time Range:** - Specify `hours` for recent history (e.g., `hours=24` for last 24 hours) - OR specify `start_date` and `end_date` for custom range - Defaults to last 24 hours if neither provided  **Grouping:** - `minute`: High-resolution (for short time ranges) - `hour`: Standard resolution (default) - `day`: For longer time ranges - `week`, `month`: For historical trends  **Response:** - Time-series metrics (avg, p50, p95, p99 latencies) - Summary statistics across the entire time range - All latencies in milliseconds  **Example:** ```bash GET /v1/analytics/performance/engine?hours=24&group_by=hour ```

        :param hours: Hours of history (alternative to date range)
        :type hours: int
        :param start_date: Start date for time range
        :type start_date: datetime
        :param end_date: End date for time range
        :type end_date: datetime
        :param group_by: Time grouping (minute, hour, day, week)
        :type group_by: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_performance_analytics_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            group_by=group_by,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EnginePerformanceResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_engine_performance_analytics_without_preload_content(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history (alternative to date range)")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date for time range")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date for time range")] = None,
        group_by: Annotated[Optional[Annotated[str, Field(strict=True)]], Field(description="Time grouping (minute, hour, day, week)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Engine Performance

        Get engine performance metrics over time.  Query profiling data logged by the engine's profiling infrastructure. All queries are automatically filtered to your namespace.  **Time Range:** - Specify `hours` for recent history (e.g., `hours=24` for last 24 hours) - OR specify `start_date` and `end_date` for custom range - Defaults to last 24 hours if neither provided  **Grouping:** - `minute`: High-resolution (for short time ranges) - `hour`: Standard resolution (default) - `day`: For longer time ranges - `week`, `month`: For historical trends  **Response:** - Time-series metrics (avg, p50, p95, p99 latencies) - Summary statistics across the entire time range - All latencies in milliseconds  **Example:** ```bash GET /v1/analytics/performance/engine?hours=24&group_by=hour ```

        :param hours: Hours of history (alternative to date range)
        :type hours: int
        :param start_date: Start date for time range
        :type start_date: datetime
        :param end_date: End date for time range
        :type end_date: datetime
        :param group_by: Time grouping (minute, hour, day, week)
        :type group_by: str
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_performance_analytics_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            group_by=group_by,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EnginePerformanceResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_engine_performance_analytics_serialize(
        self,
        hours,
        start_date,
        end_date,
        group_by,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if hours is not None:
            
            _query_params.append(('hours', hours))
            
        if start_date is not None:
            if isinstance(start_date, datetime):
                _query_params.append(
                    (
                        'start_date',
                        start_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            if isinstance(end_date, datetime):
                _query_params.append(
                    (
                        'end_date',
                        end_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('end_date', end_date))
            
        if group_by is not None:
            
            _query_params.append(('group_by', group_by))
            
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/engine',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_engine_stage_breakdown_analytics_performance(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EngineStageBreakdownResponse:
        """Get Engine Stage Breakdown

        Get stage-level performance breakdown.  Breaks down engine performance by individual profiled stages (e.g., pipeline_run, generate_input_dataset, gcs_batch_upload).  **Use Cases:** - Identify which stages are slowest - See percentage of total time per stage - Optimize specific bottlenecks  **Response:** - Per-stage metrics (count, avg, p95, max latencies) - Total time spent in each stage - Percentage of total execution time - Sorted by total time (worst bottlenecks first)  **Example:** ```bash GET /v1/analytics/performance/engine/stages?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_stage_breakdown_analytics_performance_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EngineStageBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_engine_stage_breakdown_analytics_performance_with_http_info(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EngineStageBreakdownResponse]:
        """Get Engine Stage Breakdown

        Get stage-level performance breakdown.  Breaks down engine performance by individual profiled stages (e.g., pipeline_run, generate_input_dataset, gcs_batch_upload).  **Use Cases:** - Identify which stages are slowest - See percentage of total time per stage - Optimize specific bottlenecks  **Response:** - Per-stage metrics (count, avg, p95, max latencies) - Total time spent in each stage - Percentage of total execution time - Sorted by total time (worst bottlenecks first)  **Example:** ```bash GET /v1/analytics/performance/engine/stages?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_stage_breakdown_analytics_performance_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EngineStageBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_engine_stage_breakdown_analytics_performance_without_preload_content(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Engine Stage Breakdown

        Get stage-level performance breakdown.  Breaks down engine performance by individual profiled stages (e.g., pipeline_run, generate_input_dataset, gcs_batch_upload).  **Use Cases:** - Identify which stages are slowest - See percentage of total time per stage - Optimize specific bottlenecks  **Response:** - Per-stage metrics (count, avg, p95, max latencies) - Total time spent in each stage - Percentage of total execution time - Sorted by total time (worst bottlenecks first)  **Example:** ```bash GET /v1/analytics/performance/engine/stages?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_engine_stage_breakdown_analytics_performance_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EngineStageBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_engine_stage_breakdown_analytics_performance_serialize(
        self,
        hours,
        start_date,
        end_date,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if hours is not None:
            
            _query_params.append(('hours', hours))
            
        if start_date is not None:
            if isinstance(start_date, datetime):
                _query_params.append(
                    (
                        'start_date',
                        start_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            if isinstance(end_date, datetime):
                _query_params.append(
                    (
                        'end_date',
                        end_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('end_date', end_date))
            
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/engine/stages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_extractor_breakdown_analytics_performance_engine(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExtractorBreakdownResponse:
        """Get Extractor Breakdown

        Get extractor performance breakdown.  Shows performance metrics for each extractor and its stages.  **Use Cases:** - Compare performance across extractors - Identify slow extractor stages - Monitor specific extractor performance  **Response:** - Per-extractor, per-stage metrics - Execution counts - Latency statistics (avg, p95, max)  **Example:** ```bash GET /v1/analytics/performance/engine/extractors?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_extractor_breakdown_analytics_performance_engine_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExtractorBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_extractor_breakdown_analytics_performance_engine_with_http_info(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExtractorBreakdownResponse]:
        """Get Extractor Breakdown

        Get extractor performance breakdown.  Shows performance metrics for each extractor and its stages.  **Use Cases:** - Compare performance across extractors - Identify slow extractor stages - Monitor specific extractor performance  **Response:** - Per-extractor, per-stage metrics - Execution counts - Latency statistics (avg, p95, max)  **Example:** ```bash GET /v1/analytics/performance/engine/extractors?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_extractor_breakdown_analytics_performance_engine_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExtractorBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_extractor_breakdown_analytics_performance_engine_without_preload_content(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        start_date: Annotated[Optional[datetime], Field(description="Start date")] = None,
        end_date: Annotated[Optional[datetime], Field(description="End date")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Extractor Breakdown

        Get extractor performance breakdown.  Shows performance metrics for each extractor and its stages.  **Use Cases:** - Compare performance across extractors - Identify slow extractor stages - Monitor specific extractor performance  **Response:** - Per-extractor, per-stage metrics - Execution counts - Latency statistics (avg, p95, max)  **Example:** ```bash GET /v1/analytics/performance/engine/extractors?hours=24 ```

        :param hours: Hours of history
        :type hours: int
        :param start_date: Start date
        :type start_date: datetime
        :param end_date: End date
        :type end_date: datetime
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_extractor_breakdown_analytics_performance_engine_serialize(
            hours=hours,
            start_date=start_date,
            end_date=end_date,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ExtractorBreakdownResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_extractor_breakdown_analytics_performance_engine_serialize(
        self,
        hours,
        start_date,
        end_date,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if hours is not None:
            
            _query_params.append(('hours', hours))
            
        if start_date is not None:
            if isinstance(start_date, datetime):
                _query_params.append(
                    (
                        'start_date',
                        start_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('start_date', start_date))
            
        if end_date is not None:
            if isinstance(end_date, datetime):
                _query_params.append(
                    (
                        'end_date',
                        end_date.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('end_date', end_date))
            
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/engine/extractors',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_slowest_operations_analytics_performance_engine_slow(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="Number of operations to return")] = None,
        threshold_ms: Annotated[Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]], Field(description="Only show operations slower than this (ms)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SlowOperationsResponse:
        """Get Slowest Operations

        Get slowest individual operations.  Returns the slowest profiled operations, useful for debugging specific slow executions.  **Use Cases:** - Troubleshoot specific slow operations - Identify outliers - Deep dive into problematic executions  **Filtering:** - `threshold_ms`: Only show operations slower than this - Default: 1000ms (1 second)  **Response:** - Timestamp of slow operation - Stage name and component - Latency in milliseconds - Full metadata context  **Example:** ```bash GET /v1/analytics/performance/engine/slow-operations?hours=24&threshold_ms=5000 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of operations to return
        :type limit: int
        :param threshold_ms: Only show operations slower than this (ms)
        :type threshold_ms: float
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_slowest_operations_analytics_performance_engine_slow_serialize(
            hours=hours,
            limit=limit,
            threshold_ms=threshold_ms,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SlowOperationsResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_slowest_operations_analytics_performance_engine_slow_with_http_info(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="Number of operations to return")] = None,
        threshold_ms: Annotated[Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]], Field(description="Only show operations slower than this (ms)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SlowOperationsResponse]:
        """Get Slowest Operations

        Get slowest individual operations.  Returns the slowest profiled operations, useful for debugging specific slow executions.  **Use Cases:** - Troubleshoot specific slow operations - Identify outliers - Deep dive into problematic executions  **Filtering:** - `threshold_ms`: Only show operations slower than this - Default: 1000ms (1 second)  **Response:** - Timestamp of slow operation - Stage name and component - Latency in milliseconds - Full metadata context  **Example:** ```bash GET /v1/analytics/performance/engine/slow-operations?hours=24&threshold_ms=5000 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of operations to return
        :type limit: int
        :param threshold_ms: Only show operations slower than this (ms)
        :type threshold_ms: float
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_slowest_operations_analytics_performance_engine_slow_serialize(
            hours=hours,
            limit=limit,
            threshold_ms=threshold_ms,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SlowOperationsResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_slowest_operations_analytics_performance_engine_slow_without_preload_content(
        self,
        hours: Annotated[Optional[Annotated[int, Field(le=168, strict=True, ge=1)]], Field(description="Hours of history")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="Number of operations to return")] = None,
        threshold_ms: Annotated[Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]], Field(description="Only show operations slower than this (ms)")] = None,
        authorization: Annotated[Optional[StrictStr], Field(description="REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.")] = None,
        x_namespace: Annotated[Optional[StrictStr], Field(description="REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Slowest Operations

        Get slowest individual operations.  Returns the slowest profiled operations, useful for debugging specific slow executions.  **Use Cases:** - Troubleshoot specific slow operations - Identify outliers - Deep dive into problematic executions  **Filtering:** - `threshold_ms`: Only show operations slower than this - Default: 1000ms (1 second)  **Response:** - Timestamp of slow operation - Stage name and component - Latency in milliseconds - Full metadata context  **Example:** ```bash GET /v1/analytics/performance/engine/slow-operations?hours=24&threshold_ms=5000 ```

        :param hours: Hours of history
        :type hours: int
        :param limit: Number of operations to return
        :type limit: int
        :param threshold_ms: Only show operations slower than this (ms)
        :type threshold_ms: float
        :param authorization: REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings.
        :type authorization: str
        :param x_namespace: REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace'
        :type x_namespace: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_slowest_operations_analytics_performance_engine_slow_serialize(
            hours=hours,
            limit=limit,
            threshold_ms=threshold_ms,
            authorization=authorization,
            x_namespace=x_namespace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SlowOperationsResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_slowest_operations_analytics_performance_engine_slow_serialize(
        self,
        hours,
        limit,
        threshold_ms,
        authorization,
        x_namespace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if hours is not None:
            
            _query_params.append(('hours', hours))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if threshold_ms is not None:
            
            _query_params.append(('threshold_ms', threshold_ms))
            
        # process the header parameters
        if authorization is not None:
            _header_params['Authorization'] = authorization
        if x_namespace is not None:
            _header_params['X-Namespace'] = x_namespace
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/analytics/performance/engine/slow-operations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SpectralParams(BaseModel):
    """
    Parameters for Spectral clustering algorithm.
    """ # noqa: E501
    n_clusters: Optional[Annotated[int, Field(strict=True, ge=2)]] = Field(default=8, description="Number of clusters to form")
    eigen_solver: Optional[StrictStr] = Field(default=None, description="The eigenvalue decomposition strategy ('arpack', 'lobpcg', 'amg', or None)")
    n_components: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Number of eigenvectors to use for spectral embedding")
    random_state: Optional[StrictInt] = Field(default=42, description="Random seed for reproducibility")
    n_init: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=10, description="Number of times k-means will run with different centroid seeds")
    gamma: Optional[Union[StrictFloat, StrictInt]] = Field(default=1.0, description="Kernel coefficient for rbf, poly, sigmoid, laplacian and chi2 kernels")
    affinity: Optional[StrictStr] = Field(default='rbf', description="How to construct the affinity matrix ('nearest_neighbors', 'rbf', 'precomputed', 'precomputed_nearest_neighbors')")
    n_neighbors: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=10, description="Number of neighbors to use when constructing the affinity matrix using nearest neighbors")
    eigen_tol: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=0.0, description="Stopping criterion for eigendecomposition")
    assign_labels: Optional[StrictStr] = Field(default='kmeans', description="Strategy to assign labels in the embedding space ('kmeans' or 'discretize')")
    degree: Optional[Union[StrictFloat, StrictInt]] = Field(default=3, description="Degree of the polynomial kernel. Ignored by other kernels")
    coef0: Optional[Union[StrictFloat, StrictInt]] = Field(default=1, description="Zero coefficient for polynomial and sigmoid kernels")
    kernel_params: Optional[Dict[str, Any]] = Field(default=None, description="Parameters for the kernel function")
    n_jobs: Optional[StrictInt] = Field(default=1, description="Number of parallel jobs to run (-1 means using all processors)")
    verbose: Optional[StrictBool] = Field(default=False, description="Verbosity mode")
    __properties: ClassVar[List[str]] = ["n_clusters", "eigen_solver", "n_components", "random_state", "n_init", "gamma", "affinity", "n_neighbors", "eigen_tol", "assign_labels", "degree", "coef0", "kernel_params", "n_jobs", "verbose"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SpectralParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SpectralParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "n_clusters": obj.get("n_clusters") if obj.get("n_clusters") is not None else 8,
            "eigen_solver": obj.get("eigen_solver"),
            "n_components": obj.get("n_components"),
            "random_state": obj.get("random_state") if obj.get("random_state") is not None else 42,
            "n_init": obj.get("n_init") if obj.get("n_init") is not None else 10,
            "gamma": obj.get("gamma") if obj.get("gamma") is not None else 1.0,
            "affinity": obj.get("affinity") if obj.get("affinity") is not None else 'rbf',
            "n_neighbors": obj.get("n_neighbors") if obj.get("n_neighbors") is not None else 10,
            "eigen_tol": obj.get("eigen_tol") if obj.get("eigen_tol") is not None else 0.0,
            "assign_labels": obj.get("assign_labels") if obj.get("assign_labels") is not None else 'kmeans',
            "degree": obj.get("degree") if obj.get("degree") is not None else 3,
            "coef0": obj.get("coef0") if obj.get("coef0") is not None else 1,
            "kernel_params": obj.get("kernel_params"),
            "n_jobs": obj.get("n_jobs") if obj.get("n_jobs") is not None else 1,
            "verbose": obj.get("verbose") if obj.get("verbose") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.cluster_execution_result import ClusterExecutionResult

class TestClusterExecutionResult(unittest.TestCase):
    """ClusterExecutionResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClusterExecutionResult:
        """Test ClusterExecutionResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClusterExecutionResult`
        """
        model = ClusterExecutionResult()
        if include_optional:
            return ClusterExecutionResult(
                run_id = 'run_C',
                cluster_id = 'clust_C',
                status = 'pending',
                num_clusters = 0.0,
                num_points = 0.0,
                metrics = mixpeek.models.cluster_execution_metrics.ClusterExecutionMetrics(
                    silhouette_score = -1.0, 
                    davies_bouldin_index = 0.0, 
                    calinski_harabasz_score = 0.0, ),
                centroids = [
                    mixpeek.models.cluster_execution_centroid.ClusterExecutionCentroid(
                        cluster_id = 'cl_4', 
                        num_members = 0.0, 
                        label = '', 
                        summary = '', 
                        keywords = [
                            ''
                            ], )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                error_message = '',
                llm_labeling_errors = [
                    ''
                    ]
            )
        else:
            return ClusterExecutionResult(
                run_id = 'run_C',
                cluster_id = 'clust_C',
                status = 'pending',
                num_clusters = 0.0,
                num_points = 0.0,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testClusterExecutionResult(self):
        """Test ClusterExecutionResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.key_status import KeyStatus
from mixpeek.models.permission import Permission
from mixpeek.models.resource_scope_output import ResourceScopeOutput
from typing import Optional, Set
from typing_extensions import Self

class APIKeyCreateResponse(BaseModel):
    """
    API key response including the plaintext secret.
    """ # noqa: E501
    key_id: Optional[StrictStr] = Field(default=None, description="Public identifier for the API key.")
    key_hash: StrictStr = Field(description="SHA-256 hash of the plaintext key.")
    key_prefix: Optional[Annotated[str, Field(min_length=10, strict=True, max_length=13)]] = Field(default=None, description="Visible prefix of the API key for user identification (e.g., 'sk_abc123...'). Shows the first 10 characters of the plaintext key to help users identify which key is which in lists, without exposing the full secret. This follows industry best practices from GitHub, Stripe, and AWS. Generated automatically for new keys. Older keys may not have this field.")
    internal_id: StrictStr = Field(description="Organization internal identifier.")
    organization_id: Optional[StrictStr] = Field(default=None, description="Organization public identifier (denormalized).")
    user_id: StrictStr = Field(description="Identifier of the user who owns the key.")
    name: StrictStr = Field(description="Human-friendly key label.")
    description: Optional[StrictStr] = Field(default='', description="Optional description explaining the key usage.")
    permissions: Optional[List[Permission]] = Field(default=None, description="Permissions granted to the key (least privilege recommended).")
    scopes: Optional[List[ResourceScopeOutput]] = Field(default=None, description="Resource-level scopes restricting the key.")
    rate_limit_override: Optional[StrictInt] = Field(default=None, description="Optional per-key rate limit override in requests per minute.")
    status: Optional[KeyStatus] = Field(default=None, description="Lifecycle status of the key (active, revoked, expired).")
    expires_at: Optional[datetime] = Field(default=None, description="UTC timestamp when the key automatically expires.")
    last_used_at: Optional[datetime] = Field(default=None, description="UTC timestamp of the last successful request using the key.")
    created_at: Optional[datetime] = Field(default=None, description="UTC timestamp when the key was created.")
    created_by: Optional[StrictStr] = Field(default=None, description="User identifier that created the key.")
    revoked_at: Optional[datetime] = Field(default=None, description="UTC timestamp when the key was revoked (if applicable).")
    revoked_by: Optional[StrictStr] = Field(default=None, description="User identifier that revoked the key (if applicable).")
    key: StrictStr
    __properties: ClassVar[List[str]] = ["key_id", "key_hash", "key_prefix", "internal_id", "organization_id", "user_id", "name", "description", "permissions", "scopes", "rate_limit_override", "status", "expires_at", "last_used_at", "created_at", "created_by", "revoked_at", "revoked_by", "key"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of APIKeyCreateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item_scopes in self.scopes:
                if _item_scopes:
                    _items.append(_item_scopes.to_dict())
            _dict['scopes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of APIKeyCreateResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key_id": obj.get("key_id"),
            "key_hash": obj.get("key_hash"),
            "key_prefix": obj.get("key_prefix"),
            "internal_id": obj.get("internal_id"),
            "organization_id": obj.get("organization_id"),
            "user_id": obj.get("user_id"),
            "name": obj.get("name"),
            "description": obj.get("description") if obj.get("description") is not None else '',
            "permissions": obj.get("permissions"),
            "scopes": [ResourceScopeOutput.from_dict(_item) for _item in obj["scopes"]] if obj.get("scopes") is not None else None,
            "rate_limit_override": obj.get("rate_limit_override"),
            "status": obj.get("status"),
            "expires_at": obj.get("expires_at"),
            "last_used_at": obj.get("last_used_at"),
            "created_at": obj.get("created_at"),
            "created_by": obj.get("created_by"),
            "revoked_at": obj.get("revoked_at"),
            "revoked_by": obj.get("revoked_by"),
            "key": obj.get("key")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.step_analytics_config_output import StepAnalyticsConfigOutput

class TestStepAnalyticsConfigOutput(unittest.TestCase):
    """StepAnalyticsConfigOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StepAnalyticsConfigOutput:
        """Test StepAnalyticsConfigOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StepAnalyticsConfigOutput`
        """
        model = StepAnalyticsConfigOutput()
        if include_optional:
            return StepAnalyticsConfigOutput(
                timestamp_field = '',
                sequence_id_field = '',
                step_key_source = 'assignment_label',
                step_key_field_path = '',
                covariates = [
                    mixpeek.models.covariate_config.CovariateConfig(
                        field_path = '', 
                        covariate_type = null, 
                        name = '0', 
                        binning_strategy = 'quartiles', 
                        clustering_method = 'kmeans', 
                        n_clusters = 2.0, )
                    ],
                max_sequence_duration_days = 1.0
            )
        else:
            return StepAnalyticsConfigOutput(
                timestamp_field = '',
                sequence_id_field = '',
        )
        """

    def testStepAnalyticsConfigOutput(self):
        """Test StepAnalyticsConfigOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WebhookEventType(str, Enum):
    """
    Webhook event types for real-time notifications.  These events are emitted when significant state changes occur in the system. Webhooks subscribe to specific event types and receive notifications via configured channels (email, Slack, HTTP webhooks).  Event Naming Convention:     {resource}.{action}[.{sub-resource}[.{sub-action}]]  Examples:     - object.created: New object ingested     - collection.documents.written: Documents indexed     - cluster.execution.completed: Cluster job finished  Cache Invalidation Annotations:     Each event type includes a comment indicating recommended cache invalidation scope:     - [KEY] = Invalidate specific document/object keys     - [COLLECTION] = Invalidate collection-level cache     - [NAMESPACE] = Invalidate namespace-level cache  Event Categories:     - Object Lifecycle: Events for individual objects (create, update, delete)     - Collection Lifecycle: Events for collections (create, update, delete, documents written)     - Cluster Lifecycle: Events for clusters (create, update, delete, execution status)     - Trigger Lifecycle: Events for cluster triggers (create, update, fire, execution status)     - Taxonomy Lifecycle: Events for taxonomies (create, update, delete)  Use Cases:     - Real-time sync with external systems     - Audit trail and compliance logging     - Automated workflows triggered by state changes     - Cache invalidation for distributed systems     - Notifications to team members via Slack/email
    """

    """
    allowed enum values
    """
    OBJECT_DOT_CREATED = 'object.created'
    OBJECTS_DOT_CREATED_DOT_BATCH = 'objects.created.batch'
    OBJECT_DOT_UPDATED = 'object.updated'
    OBJECT_DOT_DELETED = 'object.deleted'
    COLLECTION_DOT_CREATED = 'collection.created'
    COLLECTION_DOT_UPDATED = 'collection.updated'
    COLLECTION_DOT_DELETED = 'collection.deleted'
    COLLECTION_DOT_DOCUMENTS_DOT_WRITTEN = 'collection.documents.written'
    CLUSTER_DOT_CREATED = 'cluster.created'
    CLUSTER_DOT_UPDATED = 'cluster.updated'
    CLUSTER_DOT_DELETED = 'cluster.deleted'
    CLUSTER_DOT_EXECUTION_DOT_STARTED = 'cluster.execution.started'
    CLUSTER_DOT_EXECUTION_DOT_COMPLETED = 'cluster.execution.completed'
    CLUSTER_DOT_EXECUTION_DOT_FAILED = 'cluster.execution.failed'
    TRIGGER_DOT_CREATED = 'trigger.created'
    TRIGGER_DOT_UPDATED = 'trigger.updated'
    TRIGGER_DOT_DELETED = 'trigger.deleted'
    TRIGGER_DOT_PAUSED = 'trigger.paused'
    TRIGGER_DOT_RESUMED = 'trigger.resumed'
    TRIGGER_DOT_FIRED = 'trigger.fired'
    TRIGGER_DOT_EXECUTION_DOT_COMPLETED = 'trigger.execution.completed'
    TRIGGER_DOT_EXECUTION_DOT_FAILED = 'trigger.execution.failed'
    TAXONOMY_DOT_CREATED = 'taxonomy.created'
    TAXONOMY_DOT_UPDATED = 'taxonomy.updated'
    TAXONOMY_DOT_DELETED = 'taxonomy.deleted'
    ALERT_DOT_CREATED = 'alert.created'
    ALERT_DOT_UPDATED = 'alert.updated'
    ALERT_DOT_DELETED = 'alert.deleted'
    ALERT_DOT_TRIGGERED = 'alert.triggered'
    ALERT_DOT_EXECUTION_DOT_COMPLETED = 'alert.execution.completed'
    ALERT_DOT_EXECUTION_DOT_FAILED = 'alert.execution.failed'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WebhookEventType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.auth_type import AuthType
from typing import Optional, Set
from typing_extensions import Self

class AuthConfig(BaseModel):
    """
    Authentication configuration for API calls.  Defines how to authenticate with external APIs using credentials stored in the organization secrets vault. Credentials are NEVER stored in the stage configuration - only references to vault secrets.  **⚠️ CRITICAL SECURITY WARNINGS**: - NEVER store actual credentials in configuration - ALWAYS use secret_ref to reference vault secrets - Credentials are encrypted at rest in vault - Decrypted values never appear in logs or API responses  **How It Works**: 1. Store secret via: POST /v1/organizations/secrets 2. Reference secret via: auth.secret_ref in stage config 3. At runtime: Secret is retrieved, decrypted, and injected into request 4. Security: Original secret value never exposed or logged  **Requirements**: - type: REQUIRED, authentication method (none, api_key, bearer, basic, custom_header) - secret_ref: REQUIRED (except for type=none), name of secret in vault - key: REQUIRED (for api_key and custom_header types), header/query param name - location: OPTIONAL (for api_key type), 'header' or 'query' (default: header)  **Supported Authentication Types**: - Bearer tokens (OAuth 2.0, JWT): Most modern APIs - API keys: Weather APIs, Maps, etc. - Basic auth: Legacy systems - Custom headers: Non-standard auth schemes
    """ # noqa: E501
    type: Optional[AuthType] = Field(default=None, description="REQUIRED. Authentication method to use. Options: none (public API), api_key (API keys), bearer (OAuth/JWT), basic (HTTP Basic Auth), custom_header (non-standard headers). See AuthType enum for detailed description of each type.")
    secret_ref: Optional[StrictStr] = Field(default=None, description="REQUIRED (except for type=none). Name of secret in organization vault. The secret must be created first via POST /v1/organizations/secrets. Format: Use the exact secret_name from vault (e.g., 'stripe_api_key'). At runtime, the secret value is securely retrieved and decrypted. The decrypted value is then injected into the request per auth type. SECURITY: NEVER store actual credentials here - only the reference name. Examples: 'stripe_api_key', 'github_pat', 'weather_api_key'")
    location: Optional[StrictStr] = Field(default=None, description="OPTIONAL (for api_key type only). Where to inject the API key. Options: 'header' (recommended, more secure) or 'query' (less secure). Default: 'header' if not specified. Query parameters appear in URLs and logs - use headers when possible. Ignored for other auth types (bearer, basic, custom_header).")
    key: Optional[StrictStr] = Field(default=None, description="REQUIRED (for api_key and custom_header types). Header name or query parameter name for authentication. For api_key with location=header: Header name like 'X-API-Key', 'Authorization'. For api_key with location=query: Query param like 'apikey', 'api_key', 'key'. For custom_header: Any custom header name like 'X-Custom-Auth', 'X-Token'. Ignored for bearer and basic types (use standard headers). Common patterns: 'X-API-Key', 'Authorization', 'X-Auth-Token'")
    __properties: ClassVar[List[str]] = ["type", "secret_ref", "location", "key"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "secret_ref": obj.get("secret_ref"),
            "location": obj.get("location"),
            "key": obj.get("key")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.adhoc_execution_detail import AdhocExecutionDetail

class TestAdhocExecutionDetail(unittest.TestCase):
    """AdhocExecutionDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdhocExecutionDetail:
        """Test AdhocExecutionDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdhocExecutionDetail`
        """
        model = AdhocExecutionDetail()
        if include_optional:
            return AdhocExecutionDetail(
                execution_id = '',
                execution_mode = '',
                status = '',
                timestamp = None,
                duration_ms = 0.0,
                credits_used = 0.0,
                total_processed = 0.0,
                total_returned = 0.0,
                cache_hit_rate = 0.0,
                query_summary = '',
                stages_completed = 0.0,
                total_stages = 0.0,
                collection_ids = [
                    ''
                    ],
                inputs = '',
                inputs_hash = ''
            )
        else:
            return AdhocExecutionDetail(
                execution_id = '',
                execution_mode = '',
                status = '',
                timestamp = None,
                duration_ms = 0.0,
                credits_used = 0.0,
                total_processed = 0.0,
                total_returned = 0.0,
                stages_completed = 0.0,
                total_stages = 0.0,
        )
        """

    def testAdhocExecutionDetail(self):
        """Test AdhocExecutionDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BucketSchemaFieldType(str, Enum):
    """
    Supported data types for bucket schema fields.  Types fall into two categories:  1. **Metadata Types** (JSON types):    - Stored as object metadata    - Standard JSON-compatible types    - Not processed by extractors (unless explicitly mapped)    - Examples: string, number, boolean, date  2. **File Types** (blobs):    - Stored as files/blobs    - Processed by extractors    - Require file content (URL or base64)    - Examples: text, image, video, pdf  **GIF Special Handling**:     GIF files can be declared as either IMAGE or VIDEO type:      - As IMAGE: GIF is embedded as a single static image (first frame)     - As VIDEO: GIF is decomposed frame-by-frame with embeddings per frame      The multimodal extractor detects GIFs via MIME type (image/gif) and routes     them based on your schema declaration. Use VIDEO for animated GIFs where     frame-level search is needed, IMAGE for static/thumbnail use cases.  NOTE: For retriever input schemas that need to accept document references (e.g., \"find similar documents\"), use RetrieverInputSchemaFieldType instead, which includes all bucket types plus document_reference.
    """

    """
    allowed enum values
    """
    STRING = 'string'
    NUMBER = 'number'
    INTEGER = 'integer'
    FLOAT = 'float'
    BOOLEAN = 'boolean'
    OBJECT = 'object'
    ARRAY = 'array'
    DATE = 'date'
    DATETIME = 'datetime'
    TEXT = 'text'
    IMAGE = 'image'
    AUDIO = 'audio'
    VIDEO = 'video'
    PDF = 'pdf'
    EXCEL = 'excel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BucketSchemaFieldType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.components_config import ComponentsConfig
from mixpeek.models.custom_cta import CustomCTA
from mixpeek.models.external_link import ExternalLink
from mixpeek.models.field_config import FieldConfig
from mixpeek.models.input_rendering_config_input import InputRenderingConfigInput
from mixpeek.models.layout_config import LayoutConfig
from mixpeek.models.markdown_content import MarkdownContent
from mixpeek.models.seo_config import SEOConfig
from mixpeek.models.theme_config import ThemeConfig
from typing import Optional, Set
from typing_extensions import Self

class DisplayConfigInput(BaseModel):
    """
    Display configuration for public retriever UI.  This model defines how the public search interface should be rendered, including input fields, theme, layout, and result card configuration.  The frontend (apps.mixpeek.com) uses this to dynamically build the UI without hardcoded components.
    """ # noqa: E501
    title: StrictStr = Field(description="Title/heading for the public search page")
    description: Optional[StrictStr] = Field(default=None, description="Optional description/subtitle for the page")
    logo_url: Optional[StrictStr] = Field(default=None, description="URL to logo image")
    icon_base64: Optional[Annotated[str, Field(strict=True, max_length=300000)]] = Field(default=None, description="Base64 encoded icon/favicon (data URI format recommended). Max size: ~200KB encoded. Use for small icons that should be embedded. Example: 'data:image/png;base64,iVBORw0KGgo...'")
    seo: Optional[SEOConfig] = Field(default=None, description="SEO configuration for search engine and social media discoverability. Auto-generated during publishing with sensible defaults inferred from title, description, and retriever metadata. All fields can be overridden.")
    markdowns: Optional[List[MarkdownContent]] = Field(default=None, description="Array of markdown content sections for documentation, guides, or informational modals. Each section has a title and markdown-formatted content. Displayed in modals, expandable sections, or tabs on the public interface. Examples: 'How it Works', 'Search Guide', 'About', 'FAQ', etc.")
    theme: Optional[ThemeConfig] = Field(default=None, description="Theme/styling configuration")
    inputs: List[InputRenderingConfigInput] = Field(description="List of input fields to render in the search interface. Each input maps to a field in the retriever's input_schema. Frontend uses the field_schema to render the appropriate component type.")
    layout: Optional[LayoutConfig] = Field(default=None, description="Layout configuration for results")
    exposed_fields: Annotated[List[StrictStr], Field(min_length=1)] = Field(description="List of document metadata fields to show in results. Only these fields are returned to end users.")
    components: Optional[ComponentsConfig] = Field(default=None, description="Configuration for UI components including search inputs, filters, and result card display options.")
    field_config: Optional[Dict[str, FieldConfig]] = Field(default=None, description="Configuration for how each field should be displayed. Keys are field names (must be subset of exposed_fields). Values are FieldConfig objects specifying format and display options.")
    custom_cta: Optional[CustomCTA] = Field(default=None, description="Optional custom call-to-action button displayed in the header bar. Opens a markdown modal when clicked.")
    external_links: Optional[List[ExternalLink]] = Field(default=None, description="External resource links for this retriever (GitHub repos, blog posts, docs, etc.). Displayed on homepage and retriever listing pages to provide additional context.")
    template_type: Optional[StrictStr] = Field(default=None, description="Template identifier for frontend rendering. Built-in templates: portrait-gallery, media-search, document-search. Custom templates can use any string identifier.")
    field_mappings: Optional[Dict[str, StrictStr]] = Field(default=None, description="Field mappings from collection output fields to template display slots. Maps template slot names (e.g., 'thumbnail', 'title') to actual field names in the search results.")
    extensions: Optional[Dict[str, Any]] = Field(default=None, description="Generic extensions for template-specific configuration. Allows templates to store custom config without schema changes.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["title", "description", "logo_url", "icon_base64", "seo", "markdowns", "theme", "inputs", "layout", "exposed_fields", "components", "field_config", "custom_cta", "external_links", "template_type", "field_mappings", "extensions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DisplayConfigInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of seo
        if self.seo:
            _dict['seo'] = self.seo.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in markdowns (list)
        _items = []
        if self.markdowns:
            for _item_markdowns in self.markdowns:
                if _item_markdowns:
                    _items.append(_item_markdowns.to_dict())
            _dict['markdowns'] = _items
        # override the default output from pydantic by calling `to_dict()` of theme
        if self.theme:
            _dict['theme'] = self.theme.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in inputs (list)
        _items = []
        if self.inputs:
            for _item_inputs in self.inputs:
                if _item_inputs:
                    _items.append(_item_inputs.to_dict())
            _dict['inputs'] = _items
        # override the default output from pydantic by calling `to_dict()` of layout
        if self.layout:
            _dict['layout'] = self.layout.to_dict()
        # override the default output from pydantic by calling `to_dict()` of components
        if self.components:
            _dict['components'] = self.components.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in field_config (dict)
        _field_dict = {}
        if self.field_config:
            for _key_field_config in self.field_config:
                if self.field_config[_key_field_config]:
                    _field_dict[_key_field_config] = self.field_config[_key_field_config].to_dict()
            _dict['field_config'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of custom_cta
        if self.custom_cta:
            _dict['custom_cta'] = self.custom_cta.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in external_links (list)
        _items = []
        if self.external_links:
            for _item_external_links in self.external_links:
                if _item_external_links:
                    _items.append(_item_external_links.to_dict())
            _dict['external_links'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DisplayConfigInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "description": obj.get("description"),
            "logo_url": obj.get("logo_url"),
            "icon_base64": obj.get("icon_base64"),
            "seo": SEOConfig.from_dict(obj["seo"]) if obj.get("seo") is not None else None,
            "markdowns": [MarkdownContent.from_dict(_item) for _item in obj["markdowns"]] if obj.get("markdowns") is not None else None,
            "theme": ThemeConfig.from_dict(obj["theme"]) if obj.get("theme") is not None else None,
            "inputs": [InputRenderingConfigInput.from_dict(_item) for _item in obj["inputs"]] if obj.get("inputs") is not None else None,
            "layout": LayoutConfig.from_dict(obj["layout"]) if obj.get("layout") is not None else None,
            "exposed_fields": obj.get("exposed_fields"),
            "components": ComponentsConfig.from_dict(obj["components"]) if obj.get("components") is not None else None,
            "field_config": dict(
                (_k, FieldConfig.from_dict(_v))
                for _k, _v in obj["field_config"].items()
            )
            if obj.get("field_config") is not None
            else None,
            "custom_cta": CustomCTA.from_dict(obj["custom_cta"]) if obj.get("custom_cta") is not None else None,
            "external_links": [ExternalLink.from_dict(_item) for _item in obj["external_links"]] if obj.get("external_links") is not None else None,
            "template_type": obj.get("template_type"),
            "field_mappings": obj.get("field_mappings"),
            "extensions": obj.get("extensions")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


